translate.tools.pomerge

Package translate :: Package tools :: Module pomerge |
[hide private]
[frames] | no frames]

# Module pomerge

source code

Merges XLIFF and Gettext PO localization files

Snippet file produced by pogrep or updated by a translator can be merged into existing files

See: http://translate.sourceforge.net/wiki/toolkit/pomerge for examples and usage instructions

Functions | [hide private]
mergestores(store1, store2, mergeblanks, mergecomments) Take any new translations in store2 and write them into store1. | source code
Boolean |
str2bool(option) Convert a string value to boolean | source code
mergestore(inputfile, outputfile, templatefile, mergeblanks="no", mergecomments="yes") | source code
main() | source code

Imports: sys, factory, poheader

Function Details | [hide private]

### str2bool(option) | source code
Convert a string value to boolean Parameters: `option` (String) - yes, true, 1, no, false, 0 Returns: Boolean